@@ -84,7 +84,7 @@ if [ $BuildCrossFPC = "yes" ]; then
 fi
 
 if [ "x$Params" != "x" ]; then
-  Params="$Params targets=i386-win32"
+  Params="$Params targets=$Targets"
   echo "calling update_cross_fpc.sh $Params ..."
   ./update_cross_fpc.sh $Params || exit
 fi
@@ -122,7 +122,7 @@ if [ $BuildCrossWin32DEB = "yes" ]; then
   Arch=i386
   PackageName=fpc_crosswin32
   ResourceDir=$CurDir/debian_crosswin32
-  FPCBuildDir=/tmp/fpc_build
+  FPCBuildDir=~/tmp/fpc_build
   FPCDeb=$CurDir/${PackageName}_${FPCVersion}-${FPCRelease}_$Arch.deb
   DebianInstallDir=$FPCBuildDir/usr
   DebianRulezDir=$FPCBuildDir/DEBIAN/
@@ -160,7 +160,7 @@ if [ $BuildCrossWin32DEB = "yes" ]; then
     cd ${BinUtilsDir}
     for binutility in $(ls -B ${BinUtilsPrefix}*); do
       NewName=$(echo $binutility | sed -e "s#^$BinUtilsPrefix##")
-      NewFileName="fpc-${TargetCPU}-${TargetOS}-$NewName"
+      NewFileName="${TargetCPU}-${TargetOS}-$NewName"
       if [ $NewName = "windres" ]; then
         # windres needs two names:
         # - the Makefiles expects without prefix fpc-
@@ -216,7 +216,7 @@ if [ $BuildCrossWin32DEB = "yes" ]; then
     chmod a+x $DebianRulezDir/postinst
   fi
 
-  # create postinst if needed
+  # create postrm if needed
   if [ -f "$ResourceDir/postrm" ]; then
     echo "creating DEBIAN/postrm file"
     cat $ResourceDir/postrm | sed -e "s/FPCVERSION/$FPCVersion/g" > $DebianRulezDir/postrm
